"""
Model exported as python.
Name : heatmap
Group : 
With QGIS : 32601
"""

from qgis.core import QgsProcessing
from qgis.core import QgsProcessingAlgorithm
from qgis.core import QgsProcessingMultiStepFeedback
from qgis.core import QgsProcessingParameterRasterDestination
from qgis.core import QgsProcessingParameterVectorLayer
import processing


class Heatmap(QgsProcessingAlgorithm):

    def initAlgorithm(self, config=None):
        self.addParameter(QgsProcessingParameterRasterDestination('Heatmapyear', 'heatmap@Year', createByDefault=True, defaultValue=None))
        self.addParameter(QgsProcessingParameterVectorLayer('jobsyear', 'jobs@year', types=[QgsProcessing.TypeVectorPoint], defaultValue=None))

    def processAlgorithm(self, parameters, context, model_feedback):
        # Use a multi-step feedback, so that individual child algorithm progress reports are adjusted for the
        # overall progress through the model
        feedback = QgsProcessingMultiStepFeedback(1, model_feedback)
        results = {}
        outputs = {}

        # Heatmap (Kernel Density Estimation)
        alg_params = {
            'DECAY': 0,
            'INPUT': parameters['jobsyear'],
            'KERNEL': 0,  # Quartic
            'OUTPUT_VALUE': 1,  # Scaled
            'PIXEL_SIZE': 100,
            'RADIUS': 2000,
            'RADIUS_FIELD': '',
            'WEIGHT_FIELD': 'BANEN',
            'OUTPUT': parameters['Heatmapyear']
        }
        outputs['HeatmapKernelDensityEstimation'] = processing.run('qgis:heatmapkerneldensityestimation', alg_params, context=context, feedback=feedback, is_child_algorithm=True)
        results['Heatmapyear'] = outputs['HeatmapKernelDensityEstimation']['OUTPUT']
        return results

    def name(self):
        return 'heatmap'

    def displayName(self):
        return 'heatmap'

    def group(self):
        return ''

    def groupId(self):
        return ''

    def createInstance(self):
        return Heatmap()
