#############################################################
# Analysis 1 - logistic jobs data selection per corop region
#############################################################

rm(list=ls())
library(tools)
library(tidyverse)

# list lisa csv files of the years stored in the folder
directory <- "data/Lisa_years"
files <- list.files(path = directory, pattern = NULL, all.files = FALSE,
                    full.names = TRUE, recursive = FALSE, ignore.case = FALSE, 
                    include.dirs = FALSE, no.. = FALSE)

# SBI definition logistics, agrofood, tech/manufacturing and other sectors
## here we do not include estimates for manually checked logistics, as these may inflate regional figures

logistics <- c("45111" , "45191" , "45311" , "45312" , "45401" , "46211" , "46212" , "46213" ,
               "46214" , "46215" , "46216" , "46217" , "46218" , "46219" , "4622" , "46231" , 
               "46232" , "46241" , "46242" , "46311" , "46312" , "4632" , "46331" , "46332" , 
               "4634" , "4635" , "4636" , "4637" , "46381" , "46382" , "46383" , "46384" , 
               "46389" , "4639" , "46411" , "46412" , "46421" , "46422" , "46423" , "46424" , 
               "46425" , "46429" , "46431" , "46432" , "46433" , "46434" , "46435" , "46436" , 
               "46441" , "46442" , "4645" , "46461" , "46462" , "46471" , "46472" , "46473" , 
               "4648" , "46491" , "46492" , "46493" , "46494" , "46495" , "46496" , "46497" , 
               "46498" , "46499" , "4651" , "4652" , "4661" , "4662" , "4663" , "4664" , "4665" ,
               "4666" , "46681" , "46682" , "46691" , "46692" , "46693" , "46694" , "46695" , 
               "46696" , "46697" , "46699" , "46711" , "46712" , "46713" , "46721" , "46722" , 
               "46723" , "46731" , "46732" , "46733" , "46734" , "46735" , "46736" , "46737" ,
               "46738" , "46739" , "46741" , "46742" , "46751" , "46752" , "46761" , "46762" , 
               "46769" , "46771" , "46772" , "46779" , "46901" , "46902","47911","47912","47913",
               "47914","47915","47916","47918","47919", "4920" , "4941",  "50201",  "50202" , 
               "50401" , "50402" , "50403" , "5121" , "52101" , "52102" , "52109" , "5221" , 
               "5222" , "5223" , "52241" , "52242" , "52291" , "52292", "5310", "53201", "53202")

agrofood <- c("0111", "0113","0116", "0119","0121", "0124","0125", "0127","0128", "0129","0130", 
              "0141","0142","0143","0145","0146","0147","0149","0150","0161","0162","0163","0164",
              "1011", "1012","1013", "1020","1031", "1032","1039", "1041","1042", "1051","1052",
              "1061", "1062","1071", "1072","1073", "1081","10821", "10822","1083", "1084","1085",
              "1086", "1089","1091", "1092","1101", "1102","1103", "1104","1105", "1106","1107",
              "1200")

techManufacturing <- as.character(25:30)


# select sector jobs per corop region
coropjobs <- data.frame()

for (i in files) {
      # loop function through CSV files selecting sector jobs per corop region
      file_path_sans_ext(basename(i)) -> year
      year <- sub("LISA","", year)
      read.csv(i) -> lisa
      #filter(lisa, corridor == 1) -> lisa # option to select only inside corridor
      lisa$sector[lisa$SBI08 %in% logistics] <- "logistics"
      lisa$sector[lisa$SBI08 %in% agrofood] <- "agrofood"
      lisa$sector[lisa$AFDELING %in% techManufacturing] <- "techManufacturing"
      lisa$sector[is.na(lisa$sector)] <- "other"
      
      group_by(lisa, COROP, COROPC, sector)-> lisagrouped
      
      summarize(lisagrouped, jobs = sum(BANEN))-> lisasum
      row <- data.frame(year = as.numeric(year),lisasum)
      coropjobs <- rbind(coropjobs, row)
}
## write csv
write_csv(coropjobs, "processed/coropjobs_lisa2000_2010_2017.csv")
