* Coagglomeration calculations for paper Nefs c.s. 

* Clearing the dataspace
clear all


** Selecting dataset for relevant years and retain observations within the corridor **
** Please note path omitted for security reasons, replace ~ with the appropriate filepath. 

* Loop over the relevant years
forval num2 = 2000/2017 {
* Specify file path
local path_orig = "data/Lisa_years/"+"`num2'"+".csv"
* Import the dataset for each year
import delimited "`path_orig'", stringcols(3 16) clear 
* Retain the observations within the corridor
keep if corridor == 1
* Save the dataset for each year
save "processed/"+"`num2'"+".dta", replace
}

* Loop over the relevant years 
forval num2 = 2000/2017 {
		
* specify the filepath
local path = "processed/"+"`num2'"+".dta"
* load the dataset
use "`path'", clear
* retain only firms located on IBIS designated areas
keep if ibis==1

* rename variables for easier coding
rename afdeling sbi2
rename sbi08 sbi5

* generate a zero vector for logistics
gen logistics = 0
* replace with 1 if the firm fits the logistics definition (split for inspection and ease)
replace logistics = 1 if inlist(sbi5, "45111" , "45191" , "45311" , "45312" , "45401")
replace logistics = 1 if inlist(sbi5,  "46211" , "46212" , "46213" )
replace logistics = 1 if inlist(sbi5,  "46214" , "46215" , "46216" , "46217" , "46218" , "46219" , "4622" , "46231" )
replace logistics = 1 if inlist(sbi5, "46232" , "46241" , "46242" , "46311" , "46312" , "4632" , "46331" , "46332" )
replace logistics = 1 if inlist(sbi5, "4634" , "4635" , "4636" , "4637" , "46381" , "46382" , "46383" , "46384" )
replace logistics = 1 if inlist(sbi5, "46389" , "4639" , "46411" , "46412" , "46421" , "46422" , "46423" , "46424" )
replace logistics = 1 if inlist(sbi5, "46425" , "46429" , "46431" , "46432" , "46433" , "46434" , "46435" , "46436") 
replace logistics = 1 if inlist(sbi5, "46441" , "46442" , "4645" , "46461" , "46462" , "46471" , "46472" , "46473" )
replace logistics = 1 if inlist(sbi5, "4648" , "46491" , "46492" , "46493" , "46494" , "46495" , "46496" , "46497" )
replace logistics = 1 if inlist(sbi5, "46498" , "46499" , "4651" , "4652" , "4661" , "4662" , "4663" , "4664" , "4665" )
replace logistics = 1 if inlist(sbi5, "4666" , "46681" , "46682" , "46691" , "46692" , "46693" , "46694" , "46695" )
replace logistics = 1 if inlist(sbi5, "46696" , "46697" , "46699" , "46711" , "46712" , "46713" , "46721" , "46722")
replace logistics = 1 if inlist(sbi5, "46723" , "46731" , "46732" , "46733" , "46734" , "46735" , "46736" , "46737")
replace logistics = 1 if inlist(sbi5, "46738" , "46739" , "46741" , "46742" , "46751" , "46752" , "46761" , "46762")
replace logistics = 1 if inlist(sbi5, "46769" , "46771" , "46772" , "46779" , "46901" , "46902","47911","47912","47913")
replace logistics = 1 if inlist(sbi5, "47914","47915","47916","47918","47919", "4920" , "4941",  "50201",  "50202" ) 
replace logistics = 1 if inlist(sbi5, "50401" , "50402" , "50403" , "5121" , "52101" , "52102" , "52109" , "5221" )
replace logistics = 1 if inlist(sbi5, "5222" , "5223" , "52241" , "52242" , "52291" , "52292", "5310", "53201", "53202")

* generate a placeholder code for the 'logistics industry' that is a union of individual 3-digit codes code '999' an the relevant 3-digit code for non-logistics industries
gen sbi2l = sbi2
replace sbi2l = "999" if logistics==1

* convert the variables to fit an earlier written script

* generate e for employment
gen e = banen
* generate m for spatial unit
gen m = gemnr
* generate i for industry codes
gen i = sbi2l
* generate f for filter on logistics
gen f = logistics

* convert i to an integer
destring i, replace

* retain only pertinent data to speed up calculations
keep e m i f

* generate total employment within each spatial unit
*bys m: egen tEmpcompC = sum(e)				

* generate total number of establishments within each spatial unit
bys m: egen tcompC = sum(e) 

* generate total number of establishment within the corridor
egen tcompNL = sum(e) 

* generate share of establishments per spatial unit
gen share = tcompC/tcompNL

* generate a variable x_m to represent the share of establishments within a spatial unit
gen x_m = share

* generate the square of x_m
gen x_m2 = x_m*x_m

* remove observations without employment
drop if e==0

* retain only pertinent data to speed up calculations
* m = spatial unit
* i = industry
* x_m = share
* x_m2 = x_m^2
* e = employment
* f = filter for logistics
keep m i x_m x_m2 e	f		// gewijzigd

* sort the data by spatial unit and industry
sort m i 

* reorder the data by spatial unit industry shares and employment
order  m i e x_m x_m2 e	

* save the reduced dataset in the working directory for future use
save temp, replace

** pre-calculate fixed numerator for future use
* generate a cumulative count of observations within each spatial unit
bys m: gen counter=_n

* retain a single observation per spatial unit
drop if counter>1

* calculate sum of squared shares over all m
egen ssm = sum(x_m2)

* substract from 1 and save as a scalar for future use 
scalar ssm = 1 - ssm

** reload the full dataset including industries
use temp, clear

* by spatial unit m and by industry i generate total employment
bys m i: egen i_compC = sum(e)		

* by industry i generate total employment
bys i: egen i_compNL = sum(e)

* calculate share of industry i in total employment
gen si_comp = i_compC/ i_compNL

* generate calculate variable as s_mi (share spatial unit m in industry i)
gen s_mi = si_comp

* substract share of industry from industry employemnt
gen c1 = s_mi-x_m

* retain only one observation per industry within each spatial unit
bys m i: gen counter=_n
drop if counter>1

*retain pertinent data, reoder and save
keep m i c1 f 
order m i c1 f
save "e_shares", replace

* retain each industry once
bys i: gen counter=_n
drop if counter>1
drop if i == 0

* keep only the industry codes and filter data
keep i f

* save the list as a temporary file
tempfile temp2

* save the list a a datafile
save "temp2", replace

* load the list
use "temp2", clear

* remove all non logistics industry codes
drop if f==0

* rename resulting list i as j
rename i j

* cross using the full industry list (reintroducing i)
cross using "temp2"

* remove filter variable
drop f

* sort the data on industry code
sort i j

* order data in order i j
order i j

* remove diagonal
drop if i==j

* calculate length of list as _N
scalar number = _N

* generate coagglomeration variable for results
gen coagg = .

* save the result in the working directory as 'masterlist'
save "masterlist", replace

* open the employment shares file and remove the filter variable and save
use "e_shares", clear
drop f
save "e_shares", replace

* open the masterlist
use "masterlist", clear

** start a loop over the masterlist 

* set loop starting value
local k = 1

* set up a progress counter
local old_perc = 0

* start loop
while `k' <= _N{
* save industry codes being processed as scalar	
scalar _i = i[`k']
scalar _j = j[`k']

* display for reference
di _i
di _j

* open employment shares
use "e_shares", clear

* retain pertinent industry pairs (OR)
keep if i == _i | i ==_j

* take employment shares and save these 
gen ti = 0
gen tj = 0
replace ti = c1 if i == _i
replace tj = c1 if i == _j


* sum the employment shares over spatial units
bys m: egen si = sum(ti)
bys m: egen sj = sum(tj)

* multiply the sums
gen tot = si*sj

* keep one spatial unit 
bys m: gen counter=_n
drop if counter>1

* take the sum of all si*sj
egen all = sum(tot)

* calculate coagg measure based on previous result and saved scalar ssm
gen coagg = all / ssm
* save the result as a scalar
scalar r = coagg

* Open the masterlist
use "masterlist", clear

* save the result in the masterlist
replace coagg = r in `k'
save "masterlist", replace

* print progress
local percentage = round(`k'/number,0.01)*100
if `percentage'>`old_perc'{
cls
n: di `percentage' "%"

}
* set progress
local old_perc = `percentage'
local k = `k'+1
*if mod(`k', number/100) == 0{
*n: di `k'/number
*}
*}
}

* save the result for the appropriate year
rename coagg coagg`num2'
save "processed/coagg`num2'.dta", replace
export delimited using "processed/Coagg`num2'csv", delimiter(";") replace
}








