######################################
# Analysis 2 - Coagglomeration graphs
######################################

rm(list=ls())
library(tidyverse)

## top 10 barchart
top <- read_csv2("processed/coag_top.csv") # read results of the Stata script

plot.new()
top |> select(Top, Translation, `2017`,`2011`,`2000`) -> top
factor(top$Translation, levels = top$Translation[order(top$Top, decreasing = FALSE)]) -> top$Translation
top |> pivot_longer(-c(Translation, Top)) |>
      ggplot(aes(x = Translation, y=value, fill = name)) +
            geom_bar(stat = "identity", position = "dodge") +
            scale_fill_brewer(name = "",palette = "Greens") +
            theme_bw(base_size = 20) + theme(legend.position = "top") +
            scale_x_discrete(labels = function(x) str_wrap(x, width = 10)) +
            ylab("co-agglomeration index") + xlab("sector")
dev.copy(png, file = "plots/coag_top.png", width=1500,height=1000)
dev.off() ### or save highres as A4 pdf

## bottom 10 barchart
bottom <- read_csv2("processed/coag_bottom.csv") # read results of the Stata script

plot.new()
bottom |> select(Top, Translation, `2017`,`2011`,`2000`) -> bottom
factor(bottom$Translation, levels = bottom$Translation[order(bottom$Top, decreasing = TRUE)]) -> bottom$Translation
bottom |> pivot_longer(-c(Translation, Top)) |>
      ggplot(aes(x = Translation, y=value, fill = name)) +
            geom_bar(stat = "identity",position = "dodge") +
            scale_fill_brewer(name = "",palette = "Reds") +
            theme_bw(base_size = 20) + theme(legend.position = "top") +
            scale_x_discrete(labels = function(x) str_wrap(x, width = 10)) +
            ylab("co-agglomeration index") + xlab("sector")
dev.copy(png, file = "plots/coag_bottom.png", width=1500,height=1000)
dev.off() ### or save highres as A4 pdf
