################################################
# Analysis 3 - shiftshare analysis
################################################

rm(list=ls())
library(tools)
library(tidyverse)
library(RColorBrewer)

# Prepare data for shift share analysis and evaluation framework (figures 5 and 6 in paper)

## define logistics sector
logistics <- c("45111" , "45191" , "45311" , "45312" , "45401" , "46211" , "46212" , "46213" ,
               "46214" , "46215" , "46216" , "46217" , "46218" , "46219" , "4622" , "46231" , 
               "46232" , "46241" , "46242" , "46311" , "46312" , "4632" , "46331" , "46332" , 
               "4634" , "4635" , "4636" , "4637" , "46381" , "46382" , "46383" , "46384" , 
               "46389" , "4639" , "46411" , "46412" , "46421" , "46422" , "46423" , "46424" , 
               "46425" , "46429" , "46431" , "46432" , "46433" , "46434" , "46435" , "46436" , 
               "46441" , "46442" , "4645" , "46461" , "46462" , "46471" , "46472" , "46473" , 
               "4648" , "46491" , "46492" , "46493" , "46494" , "46495" , "46496" , "46497" , 
               "46498" , "46499" , "4651" , "4652" , "4661" , "4662" , "4663" , "4664" , "4665" ,
               "4666" , "46681" , "46682" , "46691" , "46692" , "46693" , "46694" , "46695" , 
               "46696" , "46697" , "46699" , "46711" , "46712" , "46713" , "46721" , "46722" , 
               "46723" , "46731" , "46732" , "46733" , "46734" , "46735" , "46736" , "46737" ,
               "46738" , "46739" , "46741" , "46742" , "46751" , "46752" , "46761" , "46762" , 
               "46769" , "46771" , "46772" , "46779" , "46901" , "46902","47911","47912","47913",
               "47914","47915","47916","47918","47919", "4920" , "4941",  "50201",  "50202" , 
               "50401" , "50402" , "50403" , "5121" , "52101" , "52102" , "52109" , "5221" , 
               "5222" , "5223" , "52241" , "52242" , "52291" , "52292", "5310", "53201", "53202")

## compute location quotient in 2000 and 2017
### 2017
lisa2017 <- read_csv("data/Lisa_years/LISA2017.csv")
lisa2017$sector[lisa2017$SBI08 %in% logistics] <- "logistics"
lisa2017 %>% filter(sector == "logistics") -> lisa2017logis
sum(lisa2017logis$BANEN) -> p
sum(lisa2017$BANEN) -> q
lq_nat17 <- p/q # national location quotient is logistics jobs / total jobs
lisa2017 %>% group_by(COROP, COROPC) %>% summarise(reg_jobs17 = sum(BANEN)) -> r # regional LQ idem
lisa2017 %>% filter(sector == "logistics") %>% group_by(COROP, COROPC)  %>%
      summarise(reg_logis17 = sum(BANEN)) -> s
left_join(r,s)-> lq2017
### 2000
lisa2000 <- read_csv("data/Lisa_years/LISA2000.csv")
lisa2000$sector[lisa2000$SBI08 %in% logistics] <- "logistics"
lisa2000 %>% filter(sector == "logistics") -> lisa2000logis
sum(lisa2000logis$BANEN) -> p
sum(lisa2000$BANEN) -> q
lq_nat00 <- p/q
lisa2000 %>% group_by(COROP, COROPC) %>% summarise(reg_jobs00 = sum(BANEN)) -> r
lisa2000 %>% filter(sector == "logistics") %>% group_by(COROP, COROPC)  %>%
      summarise(reg_logis00 = sum(BANEN)) -> s
left_join(r,s)-> lq2000
left_join(lq2000,lq2017) -> LQ
### Compute LQ change 2000-2017 per region for Figure 6 framework
LQ %>% mutate(LQ17 = (reg_logis17/reg_jobs17)/lq_nat17, LQ00 = (reg_logis00/reg_jobs00)/lq_nat00,
              delta_LQ = LQ17-LQ00) -> LQ

## read corop job data and format
coropjobs <- read_csv("processed/coropjobs_lisa2000_2010_2017.csv") # result of Analysis1_data_selection.R
shift <-  pivot_wider(coropjobs, names_from = year, values_from = jobs) %>%
      rename(jobs2000 = `2000`, jobs2010 = `2010`,jobs2017 = `2017`)


# Shift-share analyse 2000-2017
natGrowth <- sum(shift$jobs2017)/sum(shift$jobs2000) -1 # 14.2% growth of national total employment
shift$growth <- shift$jobs2017 - shift$jobs2000 # absolute growth of each sector
## growth logistics
natLogistics <- shift %>% filter(sector == "logistics") 
natLogGrowth <-  sum(natLogistics$jobs2017)/sum(natLogistics$jobs2000) -1 # 10.6% growth of national logistics employment
logisticsPremium <- natLogGrowth - natGrowth 
## growth agrofood
natAgrofood <- shift %>% filter(sector == "agrofood")
natAgroGrowth <- sum(natAgrofood$jobs2017)/sum(natAgrofood$jobs2000) -1
agrofoodPremium <- natAgroGrowth - natGrowth
# growth techmanufacturing
natTech <- shift %>% filter(sector == "techManufacturing")
natTechGrowth <- sum(natTech$jobs2017)/sum(natTech$jobs2000) -1
techPremium <- natTechGrowth - natGrowth
# growth other sectors
natOther <- shift %>% filter(sector == "other")
natOthGrowth <- sum(natOther$jobs2017)/sum(natOther$jobs2000) -1
otherPremium <- natOthGrowth - natGrowth

## compute industrial mix effect
shift %>% filter(sector == "logistics") %>% mutate(IndustrialMix = jobs2000 * logisticsPremium) -> a
shift %>% filter(sector == "agrofood") %>% mutate(IndustrialMix = jobs2000 * agrofoodPremium) -> b
shift %>% filter(sector == "techManufacturing") %>% mutate(IndustrialMix = jobs2000 * techPremium) -> c
shift %>% filter(sector == "other") %>% mutate(IndustrialMix = jobs2000 * otherPremium) -> d
rbind(a,b,c,d) -> shift
## compute national growth effect
shift$NationalGrowth <- shift$jobs2000 * natGrowth
## compute expected change
shift$Expected <- shift$IndustrialMix + shift$NationalGrowth
## compute competitive effect (regional share)
shift$Competitive <- shift$growth - shift$Expected

## select corop regions in corridor (organized factor levels by jobs) and order data
corridor <- c('Groot-Rijnmond','Midden-Noord-Brabant', 'Noord-Limburg','West-Noord-Brabant',
   'Noordoost-Noord-Brabant','Zuidoost-Noord-Brabant','Arnhem/Nijmegen', 'Zuidoost-Zuid-Holland', 
   'Zuidwest-Gelderland','Midden-Limburg')
growthCorridor <- shift %>% filter(sector == "logistics" & COROP %in% corridor) %>%
      mutate(growthP = jobs2017/jobs2000) %>% select(COROP,growthP) ### compute growth in corridor

shift %>% filter(sector == "logistics" & COROP %in% corridor) %>%
          select(-c(sector, jobs2000, jobs2010,jobs2017)) -> a
      factor(a$COROP, levels = a$COROP[order(a$growth, decreasing = TRUE)]) ->a$COROP #order per total growth
            pivot_longer(a, -COROP) -> jobs_logistics
shift %>% filter(sector == "agrofood" & COROP %in% corridor) %>%
                  select(-c(sector, jobs2000, jobs2010,jobs2017)) -> b
      factor(b$COROP, levels = a$COROP[order(a$growth, decreasing = TRUE)]) ->b$COROP #order per total growth logistics!
               pivot_longer(b, -COROP) -> jobs_agrofood
shift %>% filter(sector == "techManufacturing" & COROP %in% corridor) %>%
                  select(-c(sector, jobs2000, jobs2010, jobs2017)) -> c
      factor(c$COROP, levels = a$COROP[order(a$growth, decreasing = TRUE)]) ->c$COROP #order per total growth logistics!
               pivot_longer(c, -COROP) -> jobs_tech
shift %>% filter(sector == "other" & COROP %in% corridor) %>%
                  select(-c(sector, jobs2000, jobs2010, jobs2017)) -> d
      factor(d$COROP, levels = a$COROP[order(a$growth, decreasing = TRUE)]) ->d$COROP #order per total growth logistics!
               pivot_longer(d, -COROP) -> jobs_other


# Horizontal barplots shiftshare analysis (figure 5)

## logistics
plot.new()
g <- jobs_logistics %>% filter(name %in% c( "NationalGrowth","IndustrialMix","Competitive")) %>%
      mutate(name = fct_relevel(name, "NationalGrowth","IndustrialMix","Competitive")) %>%
ggplot(aes(fill = name, y= COROP, x= value))
g + geom_bar(position = "stack", stat = "identity") + 
      scale_fill_brewer(name = "",palette = "Reds") +
      theme_bw(base_size = 20) + theme(legend.position = "top") +
      ylab("region") + xlab("jobs") + xlim(-15000,15000)
dev.copy(png, file = "plots/shiftshare_log.png", width=1500,height=1000)
dev.off()

## agrofood
plot.new()
g <- jobs_agrofood %>% filter(name %in% c( "NationalGrowth","IndustrialMix","Competitive")) %>%
      mutate(name = fct_relevel(name, "NationalGrowth","IndustrialMix","Competitive")) %>%
      ggplot(aes(fill = name, y= COROP, x= value))
g + geom_bar(position = "stack", stat = "identity") + 
      scale_fill_brewer(name = "",palette = "Greens") +
      theme_bw(base_size = 20) + theme(legend.position = "top") +
      ylab("region") + xlab("jobs") + xlim(-15000,15000)
dev.copy(png, file = "plots/shiftshare_agro.png", width=1500,height=1000)
dev.off()

## technmanufacturing
plot.new()
g <- jobs_tech %>% filter(name %in% c( "NationalGrowth","IndustrialMix","Competitive")) %>%
      mutate(name = fct_relevel(name, "NationalGrowth","IndustrialMix","Competitive")) %>%
      ggplot(aes(fill = name, y= COROP, x= value))
g + geom_bar(position = "stack", stat = "identity") + 
      scale_fill_brewer(name = "",palette = "Blues") +
      theme_bw(base_size = 20) + theme(legend.position = "top") +
      ylab("region") + xlab("jobs") + xlim(-15000,15000)
dev.copy(png, file = "plots/shiftshare_tech.png", width=1500,height=1000)
dev.off()

## other sectors
plot.new()
g <- jobs_other %>% filter(name %in% c( "NationalGrowth","IndustrialMix","Competitive")) %>%
      mutate(name = fct_relevel(name, "NationalGrowth","IndustrialMix","Competitive")) %>%
      ggplot(aes(fill = name, y= COROP, x= value))
g + geom_bar(position = "stack", stat = "identity") + 
      scale_fill_brewer(name = "",palette = "Greys") +
      theme_bw(base_size = 20) + theme(legend.position = "top") +
      ylab("region") + xlab("jobs")
dev.copy(png, file = "plots/shiftshare_other.png", width=1500,height=1000)
dev.off()
 
              
# scatterplots for evaluation framework (figure 6)

## read DC footprint data and join with job and LQ data
footgrowth_corop <- read_csv("processed/footgrowth_corop.csv") # result from Analysis1_corop_data_selection.R

footgrowth_corop %>% rename(COROPC = Corop_nr) %>% select(COROPC,`2000`,`2017`,growth17) -> g
jobs_logistics %>% pivot_wider(names_from = name) -> f
f %>% left_join(g) %>%
      left_join(LQ) -> frame
frame %>% mutate(policy = case_when(
      COROPC %in% c(15,16,29,30,35,36,38) ~ "no",
      COROPC %in% c(33,34,37) ~ "yes")
      ) -> frame # graph data with policy attribute

## scatter plot

## twin-year graph with indexed jobs 
frame %>% mutate(index = reg_logis17/reg_logis00) -> frame
ggplot(frame, aes(label = COROP, color = policy)) +
      geom_point(aes(x = `2017`/1000, y = LQ17, size = index)) + 
      geom_text(aes(x = `2017`/1000, y = LQ17),stat = "identity", size = 6, nudge_y = -0.02) +
      geom_point(aes(x = `2000`/1000, y = LQ00, size = 1), shape = 1, stroke = 1) + 
      geom_text(aes(x = `2000`/1000, y = LQ00),stat = "identity", size = 3, nudge_y = -0.02) +
      scale_size_continuous(name = "regional share", range = c(2,10)) +
      scale_color_manual(values = c('blue','red')) +
      theme_bw(base_size = 20) +
      labs(title = "framework", x = "sectoral footprint (x1000 m2)", 
           y = "sectoral location quotient (LQ)") # save as A4 pdf

## sidebar small horizontal shiftshare barplot per group - yes or no policy
g <- frame %>% 
      group_by(policy) %>% summarise(NationalGrowth = sum(NationalGrowth), 
                                     IndustrialMix = sum(IndustrialMix),
                                    Competitive = sum(Competitive)) %>% 
      pivot_longer(!policy) %>%
      mutate(name = fct_relevel(name, "NationalGrowth","IndustrialMix","Competitive")) %>%
ggplot(aes(fill = name, y= policy, x= value))
g + geom_bar(position = "stack", stat = "identity") + 
      scale_fill_brewer(name = "",palette = "Reds") +
      theme_bw(base_size = 20) + theme(legend.position = "top") +
      ylab("policy") + xlab("jobs") # save as A4 pdf